@@ -457,37 +457,8 @@ class RecurringTransaction(Adapter):
         request   = urllib2.urlopen(self.connection)
         result    = request.read()
         
-        self._errors(operation, result)
-        
         return result
     
-    def _errors(self, operation, result):
-        """Retrieve an error (if any) and throw an exception."""
-        
-        tree      = ET.ElementTree(ET.XML(result))
-        root      = tree.getroot()
-        
-        # Get the error code
-        if root.tag.find('ErrorResponse') != -1:
-            messages  = root.getchildren()[0]
-            message   = messages.getchildren()[1]
-            code      = message.getchildren()[0].text
-            error     = message.getchildren()[1].text
-            
-            raise ARBException('(' + code + ') ' + error)
-        
-        # They also put error codes in their responses... ACK
-        if root.tag.find(operation) != -1:
-            messages  = root.getchildren()[1]
-            code      = messages.getchildren()[0]
-            
-            if code.text == 'Error':
-                message = messages.getchildren()[1]
-                code    = message.getchildren()[0].text
-                error   = message.getchildren()[1].text
-                
-                raise ARBException('(' + code + ') ' + error)
-    
     def _to_xml(self, operation):
         """Convert object attributes to an XML document."""
         
